# 'require' this file in your command generator

# central configuration file for creating ground truth data.
# replace the paths according to your local installation.
# the 'files_verbose' hash contains information about the images. If you want
# to include own images, don't hesitate to extend it. Note, however, that the
# numbers should be consecutive, i.e. your image would be 49.

# EDIT HERE path to the executable
our $vole = '/vole/binary/including/full/path';
# EDIT HERE root directory of the cmfd database, such that the subdirectories of this directory are C1_panasonic, C2_canon, C3_nikon, C4_flickr
our $db_root = '/path/to/the/dataset/';

# hackish solution, there are better ways of checking the splicing parameters
our @splice_params = qw(lnoise rot scale ljpeg gnoise gjpeg cont_scale disc_scale);
our @splice_command_params = qw(local_noise rot scale local_jpeg global_noise global_jpeg global_cont_scale global_discrete_scale);
our @splice_command_params2 = qw(lnoise_stddev angle scaling ljquality gnoise_stddev gjquality cont_scale_factor discrete_scale_factor);
our %non_range_params = (gt_type => {'none' => '--no_ground_truth', 'cmfd' => '--ground_truth_is_cmfd', 'snippet' => '--ground_truth_is_snippet'});
our %bool_flags = (jpeg_output => '--output_is_jpeg');

use File::Spec::Functions;

# IF YOU INTEND TO PROVIDE (OR EXPERIMENT) WITH YOUR OWN DATA, JUST REPLACE/EXTEND THE LIST OF DATABASE ENTRIES BELOW
our %files = (
	1 => {
		path => catfile($db_root,"C1_panasonic"),
		orig => 'red_tower.png',
		raw_copy => 'red_tower_copy.png',
		copy => 'red_tower_copy.png',
		full_snippets => ['red_tower_1.png'],
		full_snippets_alpha => ['red_tower_1_alpha.png'],
		snippets => ['red_tower_1_trim.png'],
		snippets_alpha => ['red_tower_1_trim_alpha.png'],
		ground_truth => 'red_tower_gt.png',
		gt_snippets => ['red_tower_gt_1.png'],
		opaque => 200,
		prefix => 'red_tower',
		insert_positions => '1965,75', 
		source_positions => '792,19',
		l2dist => 1,
	},
	2 => {
		path => catfile($db_root,"C1_panasonic"),
		orig => 'ship_number.png',
		raw_copy => 'ship_number_copy.png',
		copy => 'ship_number_copy.png',
		full_snippets => ['ship_number_1.png'],
		full_snippets_alpha => ['ship_number_1_alpha.png'],
		snippets => ['ship_number_1_trim.png'],
		snippets_alpha => ['ship_number_1_trim_alpha.png'],
		ground_truth => 'ship_number_gt.png',
		gt_snippets => ['ship_number_gt_1.png'],
		opaque => 200,
		prefix => 'ship',
		insert_positions => '597,1692',
		source_positions => '1349,1671',
		l2dist => 1,
	},
	3 => {
		path => catfile($db_root,"C1_panasonic"),
		orig => 'tapestry.png',
		raw_copy => 'tapestry_copy.png',
		copy => 'tapestry_copy.png',
		full_snippets => ['tapestry_1.png', 'tapestry_2.png'],
		full_snippets_alpha => ['tapestry_1_alpha.png', 'tapestry_2_alpha.png'],
		snippets => ['tapestry_1_trim.png', 'tapestry_2_trim.png'],
		snippets_alpha => ['tapestry_1_trim_alpha.png', 'tapestry_2_trim_alpha.png'],
		ground_truth => 'tapestry_gt.png',
		gt_snippets => ['tapestry_gt_1.png', 'tapestry_gt_2.png'],
		opaque => 200,
		prefix => 'tapestry',
		insert_positions => '0,1077,0,1060',
		source_positions => '0,0,0,785',
		l2dist => 1,
	},
	4 => {
		path => catfile($db_root,"C1_panasonic"),
		orig => 'beach_wood.png',
		raw_copy => 'beach_wood_copy.png',
		copy => 'beach_wood_copy.png',
		full_snippets => ['beach_wood_1.png'],
		full_snippets_alpha => ['beach_wood_1_alpha.png'],
		snippets => ['beach_wood_1_trim.png'],
		snippets_alpha => ['beach_wood_1_trim_alpha.png'],
		ground_truth => 'beach_wood_gt.png',
		gt_snippets => ['beach_wood_gt_1.png'],
		opaque => 200,
		prefix => 'beach_wood',
		insert_positions => '994,605',
		source_positions => '0,608',
		l2dist => 1,
	},
	5 => {
		path => catfile($db_root,"C1_panasonic"),
		orig => 'fisherman.png',
		raw_copy => 'fisherman_copy.png',
		copy => 'fisherman_copy.png',
		full_snippets => ['fisherman_1.png', 'fisherman_2.png'],
		full_snippets_alpha => ['fisherman_1_alpha.png', 'fisherman_2_alpha.png'],
		snippets => ['fisherman_1_trim.png', 'fisherman_2_trim.png'],
		snippets_alpha => ['fisherman_1_trim_alpha.png', 'fisherman_2_trim_alpha.png'],
		ground_truth => 'fisherman_gt.png',
		gt_snippets => ['fisherman_gt_1.png', 'fisherman_gt_2.png'],
		opaque => 200,
		prefix => 'fisherman',
		insert_positions => '1497,842,1691,615',
		source_positions => '1172,835,1687,550',
		l2dist => 1,
	},
	6 => {
		path => catfile($db_root,"C1_panasonic"),
		orig => 'port.png',
		raw_copy => 'port_copy.png',
		copy => 'port_copy.png',
		full_snippets => ['port_1.png', 'port_2.png'],
		full_snippets_alpha => ['port_1_alpha.png', 'port_2_alpha.png'],
		snippets => ['port_1_trim.png', 'port_2_trim.png'],
		snippets_alpha => ['port_1_trim_alpha.png', 'port_2_trim_alpha.png'],
		ground_truth => 'port_gt.png',
		gt_snippets => ['port_gt_1.png', 'port_gt_2.png'],
		opaque => 200,
		prefix => 'port',
		insert_positions => '2436,0,2851,0',
		source_positions => '2036,0,2036,0',
		l2dist => 1,
	},
	7 => {
		path => catfile($db_root,"C1_panasonic"),
		orig => 'hedge.png',
		raw_copy => 'hedge_copy.png',
		copy => 'hedge_copy.png',
		full_snippets => ['hedge_1.png'],
		full_snippets_alpha => ['hedge_1_alpha.png'],
		snippets => ['hedge_1_trim.png'],
		snippets_alpha => ['hedge_1_trim_alpha.png'],
		ground_truth => 'hedge_gt.png',
		gt_snippets => ['hedge_gt_1.png'],
		opaque => 200,
		prefix => 'hedge',
		insert_positions => '1418,1537',
		source_positions => '341,1549',
		l2dist => 1,
	},
	8 => {
		path => catfile($db_root,"C1_panasonic"),
		orig => 'japan_tower.png',
		raw_copy => 'japan_tower_copy.png',
		copy => 'japan_tower_copy.png',
		full_snippets => ['japan_tower_1.png'],
		full_snippets_alpha => ['japan_tower_1_alpha.png'],
		snippets => ['japan_tower_1_trim.png'],
		snippets_alpha => ['japan_tower_1_trim_alpha.png'],
		ground_truth => 'japan_tower_gt.png',
		gt_snippets => ['japan_tower_gt_1.png'],
		opaque => 200,
		prefix => 'japan_tower',
		insert_positions => '1536,652',
		source_positions => '1180,640',
		l2dist => 1,
	},
	9 => {
		path => catfile($db_root,"C1_panasonic"),
		orig => 'motorcycle.png',
		raw_copy => 'motorcycle_copy.png',
		copy => 'motorcycle_copy.png',
		full_snippets => ['motorcycle_1.png'],
		full_snippets_alpha => ['motorcycle_1_alpha.png'],
		snippets => ['motorcycle_1_trim.png'],
		snippets_alpha => ['motorcycle_1_trim_alpha.png'],
		ground_truth => 'motorcycle_gt.png',
		gt_snippets => ['motorcycle_gt_1.png'],
		opaque => 200,
		prefix => 'motorcycle',
		insert_positions => '1758,746',
		source_positions => '636,784',
		l2dist => 1,
	},
	10 => {
		path => catfile($db_root,"C1_panasonic"),
		orig => 'fountain.png',
		raw_copy => 'fountain_copy.png',
		copy => 'fountain_copy.png',
		full_snippets => ['fountain_1.png'],
		full_snippets_alpha => ['fountain_1_alpha.png'],
		snippets => ['fountain_1_trim.png'],
		snippets_alpha => ['fountain_1_trim_alpha.png'],
		ground_truth => 'fountain_gt.png',
		gt_snippets => ['fountain_gt_1.png'],
		opaque => 200,
		prefix => 'fountain',
		insert_positions => '204,1161',
		source_positions => '1729,1147',
		l2dist => 1,
	},
	11 => {
		path => catfile($db_root,"C1_panasonic"),
		orig => 'central_park.png',
		raw_copy => 'central_park_copy.png',
		copy => 'central_park_copy.png',
		full_snippets => ['central_park_1.png', 'central_park_2.png'],
		full_snippets_alpha => ['central_park_1_alpha.png', 'central_park_2_alpha.png'],
		snippets => ['central_park_1_trim.png', 'central_park_2_trim.png'],
		snippets_alpha => ['central_park_1_trim_alpha.png', 'central_park_2_trim_alpha.png'],
		ground_truth => 'central_park_gt.png',
		gt_snippets => ['central_park_gt_1.png', 'central_park_gt_2.png'],
		opaque => 200,
		prefix => 'central_park',
		insert_positions => '1040,1315,536,1356', 
		source_positions => '275,1315,1891,1329',
		l2dist => 1,
	},
	12 => {
		path => catfile($db_root,"C1_panasonic"),
		orig => 'supermarket.png',
		raw_copy => 'supermarket_copy.png',
		copy => 'supermarket_copy.png',
		full_snippets => ['supermarket_1.png'],
		full_snippets_alpha => ['supermarket_1_alpha.png'],
		snippets => ['supermarket_1_trim.png'],
		snippets_alpha => ['supermarket_1_trim_alpha.png'],
		ground_truth => 'supermarket_gt.png',
		gt_snippets => ['supermarket_gt_1.png'],
		opaque => 200,
		prefix => 'supermarket',
		insert_positions => '2027,254', 
		source_positions => '891,809',
		l2dist => 1,
	},
# C2_canon
	13 => {
		path => catfile($db_root,"C2_canon"),
		orig => 'disconnected_shift.png',
		raw_copy => 'disconnected_shift_copy.png',
		copy => 'disconnected_shift_copy.png',
		full_snippets => ['disconnected_shift_1.png'],
		full_snippets_alpha => ['disconnected_shift_1_alpha.png'],
		snippets => ['disconnected_shift_1_trim.png'],
		snippets_alpha => ['disconnected_shift_1_trim_alpha.png'],
		ground_truth => 'disconnected_shift_gt.png',
		gt_snippets => ['disconnected_shift_gt_1.png'],
		opaque => 200,
		prefix => 'disconnected_shift',
		insert_positions => '699,1255', # VERIFY
		source_positions => '687,1571', # VERIFY
		l2dist => 1,
	},
	14 => {
		path => catfile($db_root,"C2_canon"),
		orig => 'swan.png',
		raw_copy => 'swan_copy.png',
		copy => 'swan_copy.png',
		full_snippets => ['swan_1.png'],
		full_snippets_alpha => ['swan_1_alpha.png'],
		snippets => ['swan_1_trim.png'],
		snippets_alpha => ['swan_1_trim_alpha.png'],
		ground_truth => 'swan_gt.png',
		gt_snippets => ['swan_gt_1.png'],
		opaque => 200,
		prefix => 'swan',
		insert_positions => '1737,1182', # VERIFY 
		source_positions => '2850,966', # VERIFY
		l2dist => 1,
	},
	15 => {
		path => catfile($db_root,"C2_canon"),
		orig => 'dark_and_bright.png',
		raw_copy => 'dark_and_bright_copy.png',
		copy => 'dark_and_bright_copy.png',
		full_snippets => ['dark_and_bright_1.png', 'dark_and_bright_2.png', 'dark_and_bright_3.png'],
		full_snippets_alpha => ['dark_and_bright_1_alpha.png', 'dark_and_bright_2_alpha.png', 'dark_and_bright_3_alpha.png'],
		snippets => ['dark_and_bright_1_trim.png', 'dark_and_bright_2_trim.png', 'dark_and_bright_3_trim.png'],
		snippets_alpha => ['dark_and_bright_1_trim_alpha.png', 'dark_and_bright_2_trim_alpha.png', 'dark_and_bright_3_trim_alpha.png'],
		ground_truth => 'dark_and_bright_gt.png',
		gt_snippets => ['dark_and_bright_gt_1.png', 'dark_and_bright_gt_2.png', 'dark_and_bright_gt_3.png'],
		opaque => 200,
		prefix => 'dark_and_bright',
		insert_positions => '1071,570,1043,1578,3192,723', # VERIFY 
		source_positions => '1071,741,1235,1587,3024,1317', # VERIFY 
		l2dist => 1,
	},
	16 => {
		path => catfile($db_root,"C2_canon"),
		orig => 'wading.png',
		raw_copy => 'wading_copy.png',
		copy => 'wading_copy.png',
		full_snippets => ['wading_1.png', 'wading_2.png'],
		full_snippets_alpha => ['wading_1_alpha.png', 'wading_2_alpha.png'],
		snippets => ['wading_1_trim.png', 'wading_2_trim.png'],
		snippets_alpha => ['wading_1_trim_alpha.png', 'wading_2_trim_alpha.png'],
		ground_truth => 'wading_gt.png',
		gt_snippets => ['wading_gt_1.png', 'wading_gt_2.png'],
		opaque => 200,
		prefix => 'wading',
		insert_positions => '1887,1680,2107,1685', # VERIFY 
		source_positions => '1115,1512,994,1525', # VERIFY
		l2dist => 1,
	},
	17 => {
		path => catfile($db_root,"C2_canon"),
		orig => 'bricks.png',
		raw_copy => 'bricks_copy.png',
		copy => 'bricks_copy.png',
		full_snippets => ['bricks_1.png', 'bricks_2.png', 'bricks_3.png', 'bricks_4.png'],
		full_snippets_alpha => ['bricks_1_alpha.png', 'bricks_2_alpha.png', 'bricks_3_alpha.png', 'bricks_4_alpha.png'],
		snippets => ['bricks_1_trim.png', 'bricks_2_trim.png', 'bricks_3_trim.png', 'bricks_4_trim.png'],
		snippets_alpha => ['bricks_1_trim_alpha.png', 'bricks_2_trim_alpha.png', 'bricks_3_trim_alpha.png', 'bricks_4_trim_alpha.png'],
		ground_truth => 'bricks_gt.png',
		gt_snippets => ['bricks_gt_1.png', 'bricks_gt_2.png', 'bricks_gt_3.png', 'bricks_gt_4.png'],
		opaque => 200,
		prefix => 'bricks',
		insert_positions => '2025,558,1202,308,2532,693,3032,823', # VERIFY 
		source_positions => '1614,411,1636,411,1634,407,1630,378', # VERIFY 
		l2dist => 1,
	},
	18 => {
		path => catfile($db_root,"C2_canon"),
		orig => 'wood_carvings.png',
		raw_copy => 'wood_carvings_copy.png',
		copy => 'wood_carvings_copy.png',
		full_snippets => ['wood_carvings_1.png'],
		full_snippets_alpha => ['wood_carvings_1_alpha.png'],
		snippets => ['wood_carvings_1_trim.png'],
		snippets_alpha => ['wood_carvings_1_trim_alpha.png'],
		ground_truth => 'wood_carvings_gt.png',
		gt_snippets => ['wood_carvings_gt_1.png'],
		opaque => 200,
		prefix => 'wood_carvings',
		insert_positions => '1491,1116', # VERIFY 
		source_positions => '923,1156', # VERIFY 
		l2dist => 1,
	},
	19 => {
		path => catfile($db_root,"C2_canon"),
		orig => 'barrier.png',
		raw_copy => 'barrier_copy.png',
		copy => 'barrier_copy.png',
		full_snippets => ['barrier_1.png'],
		full_snippets_alpha => ['barrier_1_alpha.png'],
		snippets => ['barrier_1_trim.png'],
		snippets_alpha => ['barrier_1_trim_alpha.png'],
		ground_truth => 'barrier_gt.png',
		gt_snippets => ['barrier_gt_1.png'],
		opaque => 200,
		prefix => 'barrier',
		insert_positions => '0,781', # VERIFY 
		source_positions => '636,931', # VERIFY 
		l2dist => 1,
	},
	20 => {
		path => catfile($db_root,"C2_canon"),
		orig => 'sails.png',
		raw_copy => 'sails_copy.png',
		copy => 'sails_copy.png',
		full_snippets => ['sails_1.png'],
		full_snippets_alpha => ['sails_1_alpha.png'],
		snippets => ['sails_1_trim.png'],
		snippets_alpha => ['sails_1_trim_alpha.png'],
		ground_truth => 'sails_gt.png',
		gt_snippets => ['sails_gt_1.png'],
		opaque => 200,
		prefix => 'sails',
		insert_positions => '1759,216', # VERIFY 
		source_positions => '2080,228', # VERIFY 
		l2dist => 1,
	},
	21 => {
		path => catfile($db_root,"C2_canon"),
		orig => 'no_beach.png',
		raw_copy => 'no_beach_copy.png',
		copy => 'no_beach_copy.png',
		full_snippets => ['no_beach_1.png'],
		full_snippets_alpha => ['no_beach_1_alpha.png'],
		snippets => ['no_beach_1_trim.png'],
		snippets_alpha => ['no_beach_1_trim_alpha.png'],
		ground_truth => 'no_beach_gt.png',
		gt_snippets => ['no_beach_gt_1.png'],
		opaque => 200,
		prefix => 'no_beach',
		insert_positions => '226,966', # VERIFY 
		source_positions => '798,829', # VERIFY 
		l2dist => 1,
	},
	22 => {
		path => catfile($db_root,"C2_canon"),
		orig => 'extension.png',
		raw_copy => 'extension_copy.png',
		copy => 'extension_copy.png',
		full_snippets => ['extension_1.png'],
		full_snippets_alpha => ['extension_1_alpha.png'],
		snippets => ['extension_1_trim.png'],
		snippets_alpha => ['extension_1_trim_alpha.png'],
		ground_truth => 'extension_gt.png',
		gt_snippets => ['extension_gt_1.png'],
		opaque => 200,
		prefix => 'extension',
		insert_positions => '223,22', # VERIFY 
		source_positions => '1021,22', # VERIFY 
		l2dist => 1,
	},
	23 => {
		path => catfile($db_root,"C2_canon"),
		orig => 'jellyfish_chaos.png',
		raw_copy => 'jellyfish_chaos_copy.png',
		copy => 'jellyfish_chaos_copy.png',
		full_snippets => ['jellyfish_chaos_1.png', 'jellyfish_chaos_2.png', 'jellyfish_chaos_3.png'],
		full_snippets_alpha => ['jellyfish_chaos_1_alpha.png', 'jellyfish_chaos_2_alpha.png', 'jellyfish_chaos_3_alpha.png'],
		snippets => ['jellyfish_chaos_1_trim.png', 'jellyfish_chaos_2_trim.png', 'jellyfish_chaos_3_trim.png'],
		snippets_alpha => ['jellyfish_chaos_1_trim_alpha.png', 'jellyfish_chaos_2_trim_alpha.png', 'jellyfish_chaos_3_trim_alpha.png'],
		ground_truth => 'jellyfish_chaos_gt.png',
		gt_snippets => ['jellyfish_chaos_gt_1.png', 'jellyfish_chaos_gt_2.png', 'jellyfish_chaos_gt_3.png'],
		opaque => 200,
		prefix => 'jellyfish_chaos',
		insert_positions => '918,1850,642,1758,711,2087', # VERIFY
		source_positions => '871,511,2679,1263,1998,116', # VERIFY
		l2dist => 1,
	},
	24 => {
		path => catfile($db_root,"C2_canon"),
		orig => 'noise_pattern.png',
		raw_copy => 'noise_pattern_copy.png',
		copy => 'noise_pattern_copy.png',
		full_snippets => ['noise_pattern_1.png', 'noise_pattern_2.png'],
		full_snippets_alpha => ['noise_pattern_1_alpha.png', 'noise_pattern_2_alpha.png'],
		snippets => ['noise_pattern_1_trim.png', 'noise_pattern_2_trim.png'],
		snippets_alpha => ['noise_pattern_1_trim_alpha.png', 'noise_pattern_2_trim_alpha.png'],
		ground_truth => 'noise_pattern_gt.png',
		gt_snippets => ['noise_pattern_gt_1.png', 'noise_pattern_gt_2.png'],
		opaque => 200,
		prefix => 'noise_pattern',
		insert_positions => '272,1406,2366,1114', # VERIFY 
		source_positions => '491,1439,2027,1132', # VERIFY 
		l2dist => 1,
	},
# C3_nikon
	25 => {
		path => catfile($db_root,"C3_nikon"),
		orig => 'four_babies.png',
		raw_copy => 'four_babies_copy.png',
		copy => 'four_babies_copy.png',
		full_snippets => ['four_babies_1.png'],
		full_snippets_alpha => ['four_babies_1_alpha.png'],
		snippets => ['four_babies_1_trim.png'],
		snippets_alpha => ['four_babies_1_trim_alpha.png'],
		ground_truth => 'four_babies_gt.png',
		gt_snippets => ['four_babies_gt_1.png'],
		opaque => 200,
		prefix => 'four_babies',
		insert_positions => '0,264', # VERIFY
		source_positions => '306,375', # VERIFY
		l2dist => 1,
	},
	26 => {
		path => catfile($db_root,"C3_nikon"),
		orig => 'window.png',
		raw_copy => 'window_copy.png',
		copy => 'window_copy.png',
		full_snippets => ['window_1.png'],
		full_snippets_alpha => ['window_1_alpha.png'],
		snippets => ['window_1_trim.png'],
		snippets_alpha => ['window_1_trim_alpha.png'],
		ground_truth => 'window_gt.png',
		gt_snippets => ['window_gt_1.png'],
		opaque => 200,
		prefix => 'window',
		insert_positions => '1643,1103', # VERIFY
		source_positions => '599,1163', # VERIFY
		l2dist => 1,
	},
	27 => {
		path => catfile($db_root,"C3_nikon"),
		orig => 'egyptian.png',
		raw_copy => 'egyptian_copy.png',
		copy => 'egyptian_copy.png',
		full_snippets => ['egyptian_1.png'],
		full_snippets_alpha => ['egyptian_1_alpha.png'],
		snippets => ['egyptian_1_trim.png'],
		snippets_alpha => ['egyptian_1_trim_alpha.png'],
		ground_truth => 'egyptian_gt.png',
		gt_snippets => ['egyptian_gt_1.png'],
		opaque => 200,
		prefix => 'egyptian',
		insert_positions => '0,173', # VERIFY
		source_positions => '489,144', # VERIFY
		l2dist => 1,
	},
	28 => {
		path => catfile($db_root,"C3_nikon"),
		orig => 'stone_ghost.png',
		raw_copy => 'stone_ghost_copy.png',
		copy => 'stone_ghost_copy.png',
		full_snippets => ['stone_ghost_1.png', 'stone_ghost_2.png'],
		full_snippets_alpha => ['stone_ghost_1_alpha.png', 'stone_ghost_2_alpha.png'],
		snippets => ['stone_ghost_1_trim.png', 'stone_ghost_2_trim.png'],
		snippets_alpha => ['stone_ghost_1_trim_alpha.png', 'stone_ghost_2_trim_alpha.png'],
		ground_truth => 'stone_ghost_gt.png',
		gt_snippets => ['stone_ghost_gt_1.png', 'stone_ghost_gt_2.png'],
		prefix => 'stone_ghost',
		opaque => 200,
		insert_positions => '1133,604,1135,349',
		source_positions => '1491,584,427,347',
		l2dist => 1,
	},
	29 => {
		path => catfile($db_root,"C3_nikon"),
		orig => 'white.png',
		raw_copy => 'white_copy.png',
		copy => 'white_copy.png',
		full_snippets => ['white_1.png'],
		full_snippets_alpha => ['white_1_alpha.png'],
		snippets => ['white_1_trim.png'],
		snippets_alpha => ['white_1_trim_alpha.png'],
		ground_truth => 'white_gt.png',
		gt_snippets => ['white_gt_1.png'],
		prefix => 'white',
		opaque => 200,
		insert_positions => '1922,631', # VERIFY
		source_positions => '1044,485', # VERIFY
		l2dist => 1,
	},
	30 => {
		path => catfile($db_root,"C3_nikon"),
		orig => 'writing_history.png',
		raw_copy => 'writing_history_copy.png',
		copy => 'writing_history_copy.png',
		full_snippets => ['writing_history_1.png'],
		full_snippets_alpha => ['writing_history_1_alpha.png'],
		snippets => ['writing_history_1_trim.png'],
		snippets_alpha => ['writing_history_1_trim_alpha.png'],
		ground_truth => 'writing_history_gt.png',
		gt_snippets => ['writing_history_gt_1.png'],
		opaque => 200,
		prefix => 'writing_history',
		insert_positions => '1451,1269', # VERIFY
		source_positions => '738,932', # VERIFY
		l2dist => 1,
	},
	31 => {
		path => catfile($db_root,"C3_nikon"),
		orig => 'christmas_hedge.png',
		raw_copy => 'christmas_hedge_copy.png',
		copy => 'christmas_hedge_copy.png',
		full_snippets => ['christmas_hedge_1.png'],
		full_snippets_alpha => ['christmas_hedge_1_alpha.png', 'christmas_hedge_2_alpha.png', 'christmas_hedge_3_alpha.png'],
		snippets => ['christmas_hedge_1_trim.png', 'christmas_hedge_2_trim.png', 'christmas_hedge_3_trim.png'],
		snippets_alpha => ['christmas_hedge_1_trim_alpha.png', 'christmas_hedge_2_trim_alpha.png', 'christmas_hedge_3_trim_alpha.png'],
		ground_truth => 'christmas_hedge_gt.png',
		gt_snippets => ['christmas_hedge_gt_1.png', 'christmas_hedge_gt_2.png', 'christmas_hedge_gt_3.png'],
		opaque => 200,
		prefix => 'christmas_hedge',
		insert_positions => '1075,880,294,922,0,866', # VERIFY
		source_positions => '703,856,672,859,764,861', # VERIFY
		l2dist => 1,
	},
	32 => {
		path => catfile($db_root,"C3_nikon"),
		orig => 'mask.png',
		raw_copy => 'mask_copy.png',
		copy => 'mask_copy.png',
		full_snippets => ['mask_1.png'],
		full_snippets_alpha => ['mask_1_alpha.png', 'mask_2_alpha.png'],
		snippets => ['mask_1_trim.png', 'mask_2_trim.png'],
		snippets_alpha => ['mask_1_trim_alpha.png', 'mask_2_trim_alpha.png'],
		ground_truth => 'mask_gt.png',
		gt_snippets => ['mask_gt_1.png', 'mask_gt_2.png'],
		opaque => 200,
		prefix => 'mask',
		insert_positions => '1474,509,538,709', # VERIFY
		source_positions => '905,1475,359,2566', # VERIFY
		l2dist => 1,
	},
	33 => {
		path => catfile($db_root,"C3_nikon"),
		orig => 'berries.png',
		raw_copy => 'berries_copy.png',
		copy => 'berries_copy.png',
		full_snippets => ['berries_1.png'],
		full_snippets_alpha => ['berries_1_alpha.png', 'berries_2_alpha.png'],
		snippets => ['berries_1_trim.png', 'berries_2_trim.png'],
		snippets_alpha => ['berries_1_trim_alpha.png', 'berries_2_trim_alpha.png'],
		ground_truth => 'berries_gt.png',
		gt_snippets => ['berries_gt_1.png', 'berries_gt_2.png'],
		opaque => 200,
		prefix => 'berries',
		insert_positions => '2223,833,1026,617', # VERIFY
		source_positions => '828,959,1611,365', # VERIFY
		l2dist => 1,
	},
	34 => {
		path => catfile($db_root,"C3_nikon"),
		orig => 'sweets.png',
		raw_copy => 'sweets_copy.png',
		copy => 'sweets_copy.png',
		full_snippets => ['sweets_1.png'],
		full_snippets_alpha => ['sweets_1_alpha.png', 'sweets_2_alpha.png', 'sweets_3_alpha.png'],
		snippets => ['sweets_1_trim.png', 'sweets_2_trim.png', 'sweets_3_trim.png'],
		snippets_alpha => ['sweets_1_trim_alpha.png', 'sweets_2_trim_alpha.png', 'sweets_3_trim_alpha.png'],
		ground_truth => 'sweets_gt.png',
		gt_snippets => ['sweets_gt_1.png', 'sweets_gt_2.png', 'sweets_gt_3.png'],
		prefix => 'sweets',
		opaque => 200,
		insert_positions => '97,1374,580,1194,1038,1400', # VERIFY
		source_positions => '515,683,1427,1051,1808,1295', # VERIFY
		l2dist => 1,
	},
	35 => {
		path => catfile($db_root,"C3_nikon"),
		orig => 'lone_cat.png',
		raw_copy => 'lone_cat_copy.png',
		copy => 'lone_cat_copy.png',
		full_snippets => ['lone_cat_1.png'],
		full_snippets_alpha => ['lone_cat_1_alpha.png'],
		snippets => ['lone_cat_1_trim.png'],
		snippets_alpha => ['lone_cat_1_trim_alpha.png'],
		ground_truth => 'lone_cat_gt.png',
		gt_snippets => ['lone_cat_gt_1.png'],
		opaque => 200,
		prefix => 'lone_cat',
		insert_positions => '917,647', # VERIFY
		source_positions => '1916,641', # VERIFY
		l2dist => 1,
	},
	36 => {
		path => catfile($db_root,"C3_nikon"),
		orig => 'horses.png',
		raw_copy => 'horses_copy.png',
		copy => 'horses_copy.png',
		full_snippets => ['horses_1.png'],
		full_snippets_alpha => ['horses_1_alpha.png', 'horses_2_alpha.png'],
		snippets => ['horses_1_trim.png', 'horses_2_trim.png'],
		snippets_alpha => ['horses_1_trim_alpha.png', 'horses_2_trim_alpha.png'],
		ground_truth => 'horses_gt.png',
		gt_snippets => ['horses_gt_1.png', 'horses_gt_2.png'],
		opaque => 200,
		prefix => 'horses',
		insert_positions => '136,546,2455,551', # VERIFY
		source_positions => '483,546,2139,547', # VERIFY
		l2dist => 1,
	},
# C4_flickr
	37 => {
		path => catfile($db_root,"C4_flickr"),
		orig => 'clean_walls.png',
		raw_copy => 'clean_walls_copy.png',
		copy => 'clean_walls_copy.png',
		full_snippets => ['clean_walls_1.png'],
		full_snippets_alpha => ['clean_walls_1_alpha.png'],
		snippets => ['clean_walls_1_trim.png'],
		snippets_alpha => ['clean_walls_1_trim_alpha.png'],
		ground_truth => 'clean_walls_gt.png',
		gt_snippets => ['clean_walls_gt_1.png'],
		opaque => 200,
		prefix => 'clean_walls',
		insert_positions => '378,359',
		source_positions => '378,98',
		l2dist => 1,
	},
	38 => {
		path => catfile($db_root,"C4_flickr"),
		orig => 'giraffe.png',
		raw_copy => 'giraffe_copy.png',
		copy => 'giraffe_copy.png',
		full_snippets => ['giraffe_1.png'],
		full_snippets_alpha => ['giraffe_1_alpha.png'],
		snippets => ['giraffe_1_trim.png'],
		snippets_alpha => ['giraffe_1_trim_alpha.png'],
		ground_truth => 'giraffe_gt.png',
		gt_snippets => ['giraffe_gt_1.png'],
		opaque => 100,
		prefix => 'giraffe',
		insert_positions => '128,459', # VERIFY
		source_positions => '151,332', # VERIFY
		l2dist => 1,
	},
	39 => {
		path => catfile($db_root,"C4_flickr"),
		orig => 'threehundred.png',
		raw_copy => 'threehundred_copy.png',
		copy => 'threehundred_copy.png',
		full_snippets => ['threehundred_1.png', 'threehundred_2.png', 'threehundred_3.png', 'threehundred_4.png', 'threehundred_5.png', 'threehundred_6.png'],
		full_snippets_alpha => ['threehundred_1_alpha.png', 'threehundred_2_alpha.png', 'threehundred_3_alpha.png', 'threehundred_4_alpha.png', 'threehundred_5_alpha.png', 'threehundred_6_alpha.png'],
		snippets => ['threehundred_1_trim.png', 'threehundred_2_trim.png', 'threehundred_3_trim.png', 'threehundred_4_trim.png', 'threehundred_5_trim.png', 'threehundred_6_trim.png'],
		snippets_alpha => ['threehundred_1_trim_alpha.png', 'threehundred_2_trim_alpha.png', 'threehundred_3_trim_alpha.png', 'threehundred_4_trim_alpha.png', 'threehundred_5_trim_alpha.png', 'threehundred_6_trim_alpha.png'],
		ground_truth => 'threehundred_gt.png',
		gt_snippets => ['threehundred_gt_1.png', 'threehundred_gt_2.png', 'threehundred_gt_3.png', 'threehundred_gt_4.png', 'threehundred_gt_5.png', 'threehundred_gt_6.png'],
		opaque => 150,
		prune => 1,
		l1tol => [20,20,20,20,20,10],
		prefix => 'threehundred',
		insert_positions => '918,954,925,965,891,1056,972,1120,968,1151,964,1170', # VERIFY
		source_positions => '1415,788,1327,964,2071,1018,1165,1075,449,1110,370,1112', # VERIFY
	},
	40 => {
		path => catfile($db_root,"C4_flickr"),
		orig => 'cattle.png',
		raw_copy => 'cattle_copy.png',
		copy => 'cattle_copy.png',
		full_snippets => ['cattle_1.png'],
		full_snippets_alpha => ['cattle_1_alpha.png'],
		snippets => ['cattle_1_trim.png'],
		snippets_alpha => ['cattle_1_trim_alpha.png'],
		ground_truth => 'cattle_gt.png',
		gt_snippets => ['cattle_gt_1.png'],
		opaque => 200,
		prefix => 'cattle',
		insert_positions => '828,169', # VERIFY
		source_positions => '417,671', # VERIFY
		l2dist => 1,
	},
	41 => {
		path => catfile($db_root,"C4_flickr"),
		orig => 'kore.png',
		raw_copy => 'kore_copy.png',
		copy => 'kore_copy.png',
		full_snippets => ['kore_1.png'],
		full_snippets_alpha => ['kore_1_alpha.png'],
		snippets => ['kore_1_trim.png'],
		snippets_alpha => ['kore_1_trim_alpha.png'],
		ground_truth => 'kore_gt.png',
		gt_snippets => ['kore_gt_1.png'],
		opaque => 200,
		prefix => 'kore',
		insert_positions => '114,450', # VERIFY
		source_positions => '557,420', # VERIFY
		l2dist => 1,
	},
	42 => {
		path => catfile($db_root,"C4_flickr"),
		orig => 'scotland.png',
		raw_copy => 'scotland_copy.png',
		copy => 'scotland_copy.png',
		full_snippets => ['scotland_1.png'],
		full_snippets_alpha => ['scotland_1_alpha.png'],
		snippets => ['scotland_1_trim.png'],
		snippets_alpha => ['scotland_1_trim_alpha.png'],
		ground_truth => 'scotland_gt.png',
		gt_snippets => ['scotland_gt_1.png'],
		opaque => 200,
		prefix => 'scotland',
		insert_positions => '884,729', # VERIFY
		source_positions => '0,0', # VERIFY
		l2dist => 1,
	},
	43 => {
		path => catfile($db_root,"C4_flickr"),
		orig => 'malawi.png',
		raw_copy => 'malawi_copy.png',
		copy => 'malawi_copy.png',
		full_snippets => ['malawi_1.png', 'malawi_2.png'],
		full_snippets_alpha => ['malawi_1_alpha.png', 'malawi_2_alpha.png'],
		snippets => ['malawi_1_trim.png', 'malawi_2_trim.png'],
		snippets_alpha => ['malawi_1_trim_alpha.png', 'malawi_2_trim_alpha.png'],
		ground_truth => 'malawi_gt.png',
		gt_snippets => ['malawi_gt_1.png', 'malawi_gt_2.png'],
		opaque => 200,
		prefix => 'malawi',
		insert_positions => '2013,0,989,265', # VERIFY
		source_positions => '0,0,0,265', # VERIFY
		l2dist => 1,
	},
	44 => {
		path => catfile($db_root,"C4_flickr"),
		orig => 'tree.png',
		raw_copy => 'tree_copy.png',
		copy => 'tree_copy.png',
		full_snippets => ['tree_1.png'],
		full_snippets_alpha => ['tree_1_alpha.png'],
		snippets => ['tree_1_trim.png'],
		snippets_alpha => ['tree_1_trim_alpha.png'],
		ground_truth => 'tree_gt.png',
		gt_snippets => ['tree_gt_1.png'],
		opaque => 200,
		prefix => 'tree',
		insert_positions => '717,409', # VERIFY
		source_positions => '319,393', # VERIFY
		l2dist => 1,
	},
	45 => {
		path => catfile($db_root,"C4_flickr"),
		orig => 'sailing.png',
		raw_copy => 'sailing_copy.png',
		copy => 'sailing_copy.png',
		full_snippets => ['sailing_1.png', 'sailing_2.png'],
		full_snippets_alpha => ['sailing_1_alpha.png', 'sailing_2_alpha.png'],
		snippets => ['sailing_1_trim.png', 'sailing_2_trim.png'],
		snippets_alpha => ['sailing_1_trim_alpha.png', 'sailing_2_trim_alpha.png'],
		ground_truth => 'sailing_gt.png',
		gt_snippets => ['sailing_gt_1.png', 'sailing_gt_2.png'],
		opaque => 200,
		prefix => 'sailing',
		insert_positions => '768,2701,1088,1827', # VERIFY
		source_positions => '1419,2657,1217,2129', # VERIFY
		l2dist => 1,
	},
	46 => {
		path => catfile($db_root,"C4_flickr"),
		orig => 'statue.png',
		raw_copy => 'statue_copy.png',
		copy => 'statue_copy.png',
		full_snippets => ['statue_1.png', 'statue_2.png', 'statue_3.png', 'statue_4.png'],
		full_snippets_alpha => ['statue_1_alpha.png', 'statue_2_alpha.png', 'statue_3_alpha.png', 'statue_4_alpha.png'],
		snippets => ['statue_1_trim.png', 'statue_2_trim.png', 'statue_3_trim.png', 'statue_4_trim.png'],
		snippets_alpha => ['statue_1_trim_alpha.png', 'statue_2_trim_alpha.png', 'statue_3_trim_alpha.png', 'statue_4_trim_alpha.png'],
		ground_truth => 'statue_gt.png',
		gt_snippets => ['statue_gt_1.png', 'statue_gt_2.png', 'statue_gt_3.png', 'statue_gt_4.png'],
		prune => 1,
		opaque => 50,
		prefix => 'statue',
		insert_positions => '988,1216,956,1143,1672,1178,1651,1144', # VERIFY
		source_positions => '1778,1012,542,1142,1783,971,2061,1145', # VERIFY
		l2dist => 1,
	},
	47 => {
		path => catfile($db_root,"C4_flickr"),
		orig => 'mykene.png',
		raw_copy => 'mykene_copy.png',
		copy => 'mykene_copy.png',
		full_snippets => ['mykene_1.png', 'mykene_2.png', 'mykene_3.png', 'mykene_4.png'],
		full_snippets_alpha => ['mykene_1_alpha.png', 'mykene_2_alpha.png', 'mykene_3_alpha.png', 'mykene_4_alpha.png'],
		snippets => ['mykene_1_trim.png', 'mykene_2_trim.png', 'mykene_3_trim.png', 'mykene_4_trim.png'],
		snippets_alpha => ['mykene_1_trim_alpha.png', 'mykene_2_trim_alpha.png', 'mykene_3_trim_alpha.png', 'mykene_4_trim_alpha.png'],
		ground_truth => 'mykene_gt.png',
		gt_snippets => ['mykene_gt_1.png', 'mykene_gt_2.png', 'mykene_gt_3.png', 'mykene_gt_4.png'],
		opaque => 250,
		prune => 1,
		prefix => 'mykene',
		insert_positions => '1630,840,1865,806,1865,1027,1779,1027', # VERIFY
		source_positions => '1495,843,1959,800,2031,1017,2030,1017', # VERIFY
		l2dist => 1,
	},
	48 => {
		path => catfile($db_root,"C4_flickr"),
		orig => 'knight_moves.png',
		raw_copy => 'knight_moves_copy.png',
		copy => 'knight_moves_copy.png',
		full_snippets => ['knight_moves_1.png', 'knight_moves_2.png', 'knight_moves_3.png', 'knight_moves_4.png', 'knight_moves_5.png', 'knight_moves_6.png'],
		full_snippets_alpha => ['knight_moves_1_alpha.png', 'knight_moves_2_alpha.png', 'knight_moves_3_alpha.png', 'knight_moves_4_alpha.png', 'knight_moves_5_alpha.png', 'knight_moves_6_alpha.png'],
		snippets => ['knight_moves_1_trim.png', 'knight_moves_2_trim.png', 'knight_moves_3_trim.png', 'knight_moves_4_trim.png', 'knight_moves_5_trim.png', 'knight_moves_6_trim.png'],
		snippets_alpha => ['knight_moves_1_trim_alpha.png', 'knight_moves_2_trim_alpha.png', 'knight_moves_3_trim_alpha.png', 'knight_moves_4_trim_alpha.png', 'knight_moves_5_trim_alpha.png', 'knight_moves_6_trim_alpha.png'],
		ground_truth => 'knight_moves_gt.png',
		gt_snippets => ['knight_moves_gt_1.png', 'knight_moves_gt_2.png', 'knight_moves_gt_3.png', 'knight_moves_gt_4.png', 'knight_moves_gt_5.png', 'knight_moves_gt_6.png'],
		opaque => 100,
		prefix => 'knight_moves',
		insert_positions => '471,578,545,624,606,584,663,622,702,544,763,582', # VERIFY
		source_positions => '471,739,545,745,857,744,758,741,513,827,763,702', # VERIFY
		l2dist => 1,
	},
);


